@@ -15,15 +15,13 @@ extern void phi1(void *, void *, void *, void *, void *, void *, void *);
 /* .Call calls */
 extern SEXP glm_deterministic(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP glm_fit(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP glm_mcmc(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP glm_mcmc(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP glm_mcmcbas(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP glm_sampleworep(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP amcmc(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP deterministic(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP mcmc_new(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP mcmcbas(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP sampleworep_new(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP sampleworep(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP glm_sampleworep(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP deterministic(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP mcmc_new(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP mcmcbas(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP sampleworep_new(SEXP,SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 
 
@@ -39,15 +37,13 @@ static const R_CMethodDef CEntries[] = {
 static const R_CallMethodDef CallEntries[] = {
   {"glm_deterministic", (DL_FUNC) &glm_deterministic, 11},
   {"glm_fit",           (DL_FUNC) &glm_fit,            7},
-  {"glm_mcmc",          (DL_FUNC) &glm_mcmc,          14},
-  {"glm_mcmcbas",       (DL_FUNC) &glm_mcmcbas,       15},
-  {"glm_sampleworep",   (DL_FUNC) &glm_sampleworep,   14},
-  {"mcmc_new",          (DL_FUNC) &mcmc_new,          17},
-  {"amcmc",             (DL_FUNC) &amcmc,             16},
-  {"deterministic",     (DL_FUNC) &deterministic,      9},
-  {"mcmcbas",           (DL_FUNC) &mcmcbas,           16},
-  {"sampleworep_new",   (DL_FUNC) &sampleworep_new,       12},
-  {"sampleworep)",  (DL_FUNC) &sampleworep,   12},
+  {"glm_mcmc",          (DL_FUNC) &glm_mcmc,          15},
+  {"glm_mcmcbas",       (DL_FUNC) &glm_mcmcbas,       16},
+  {"glm_sampleworep",   (DL_FUNC) &glm_sampleworep,   15},
+  {"mcmc_new",          (DL_FUNC) &mcmc_new,          19},
+  {"deterministic",     (DL_FUNC) &deterministic,     10},
+  {"mcmcbas",           (DL_FUNC) &mcmcbas,           17},
+  {"sampleworep_new",   (DL_FUNC) &sampleworep_new,       14},
   {NULL, NULL, 0}
 };
 
